==> react-gui-common-1.3.176.tgz: package/src/components/RodoUserComponent.js <==
/* eslint-disable max-len */
/* eslint-disable react/jsx-handler-names */
import React from 'react';
import PropTypes from 'prop-types';
import ActionLink from './ActionLink';
import BaseService from '../baseContainers/BaseService';
import InputTextComponent from './inputs/InputTextComponent';

// eslint-disable-next-line import/no-extraneous-dependencies
/*
import {
	ActionLink,
	BaseService,
	InputTextComponent,
} from 'react-gui-common';
*/

class RodoService extends BaseService {
	constructor(domain) {
		super(domain);
		this.path = 'common/rodo';
	}

	personalize(id, userType) {
		return this.fetch(`${this.domain}/${this.path}/personalize/${id}?type=${userType}`, {
			method: 'GET',
		}).then(res => {
			return Promise.resolve(res);
		});
	}
}

class RodoUserComponent extends React.Component {
	constructor(props) {
		super(props);
		this.rodoService = new RodoService(props.baseRestApiUrl);
		this.state = {};
	}

	personalize(user) {
		console.log(`personalize, user.id=${user.id}`);
		const { onError, userType, requestId } = this.props;
		let id;
		if (userType === 'USER' || userType === 'PUBLIC_UNIT_MANAGER') {
			id = user.id;
		} else {
			id = requestId;
		}
		this.rodoService.personalize(id, userType)
			.then(u => {
				user.unhidden = true;
				if (userType === 'PUBLIC_UNIT_MANAGER') {
					user.managerFullName = u.firstName;
					user.filled = u.firstName !== undefined && u.firstName !== '';
				} else {
					user.firstName = u.firstName;
					user.lastName = u.lastName;
					user.filled = u.firstName !== undefined && u.firstName !== '' && u.lastName !== undefined && u.lastName !== '';
				}
				console.log('&++++', user);
				this.setState({ user });
			})
			.catch(err => {
				if (onError) {
					onError(err.message);
				}
			});
	}

	renderDetailWithPersonalizeOption() {
		const {
			id,
			colClass,
			insideTable,
			formGroup,
			label,
			showLabel,
			titleElement,
			titleElementClass,
			iconName,
			iconColor,
			iconSide,
			iconSize,
			value,
			showOnlyId,
			rendered,
			userType,
			validator,
			validators,
		} = this.props;

		const managerUser = userType === 'PUBLIC_UNIT_MANAGER';
		const applicantUser = (userType === 'DATA_ACCESS_REQ_APPLICANT' || userType === 'QUERY_REQ_APPLICANT');

		if (rendered) {
			return (
				<div className={insideTable ? '' : titleElement ? titleElementClass : colClass}>
					<div className={insideTable ? '' : 'row'}>
						<div className={insideTable ? '' : `col-md-12 ${formGroup ? 'form-group' : ''}`}>
							{label !== undefined && showLabel && !titleElement ? (
								<label className="p-label" htmlFor={id} style={{ width: '100%' }}>
									{label}
								</label>
							) : null}
							<span
								className={`p-inputtext-view icon_text ${titleElement ? ' title-element' : ''} ${
									iconName !== undefined ? iconColor : ''
								}`}
							>
								{iconSide === 'left' && iconName !== undefined ? (
									<i className={`icon mdi ${iconName} ${iconSize}`} />
								) : null}
								{(managerUser || applicantUser) ? '********' : value.id}
								{iconSide === 'right' && iconName !== undefined ? (
									<i className={`icon mdi ${iconName} ${iconSize}`} />
								) : null}
								{showOnlyId ? null : (
									<span style={{marginLeft: '10px' }} >
									<ActionLink label="Odkryj" handleClick={() => this.personalize(value)} />
									</span>
								)}
							</span>
							{validator ? validator.message(id, label, value.filled === false ? null : 'filled', validators) : null}
						</div>
					</div>
				</div>
			);
		} else {
			return (<span />);
		}
	}


	render() {
		const { id, label, colClass, value, viewType, rendered, showOnlyId, userType, validator, validators} = this.props;
		let hidden = true;
		if (userType === 'USER' || userType === 'DATA_ACCESS_REQ_APPLICANT' || userType === 'QUERY_REQ_APPLICANT') {
			hidden = value === undefined || (!value.firstName && !value.lastName);
		} else if (userType === 'PUBLIC_UNIT_MANAGER') {
			hidden = value === undefined || !value.managerFullName;
		}
		if (value && value.hidden === false) {
			hidden = false;
		}
		if (value && value.unhidden === true) {
			hidden = false;
		}
		const publicUser = value !== undefined && value.id === 0;
		const empty = value === undefined || value == null || (userType === 'USER' && value && (value.id === undefined || value.id === null));
		const applicantUser = userType === 'DATA_ACCESS_REQ_APPLICANT' || userType === 'QUERY_REQ_APPLICANT';
		const managerUser = userType === 'PUBLIC_UNIT_MANAGER';
		// console.log(`+++ hidden=${hidden}, publicUser=${publicUser}, empty=${empty}, showOnlyId=${showOnlyId}, rendered=${rendered}, userType=${userType}, user=${JSON.stringify(value)}`);
		// console.log('++++managerUserHidden:', managerUserHidden);
		if (viewType === 'LIST') {
			if (empty) {
				return (
					<span>-</span>
				);
			} else if (publicUser) {
				return (
					<span>Użytkownik niezalogowany</span>
				);
			} else if (hidden || showOnlyId) {
				return (
					<div className="row">
						<div className="col-md-6">{applicantUser || managerUser ? '********' : value.id}</div>
						{showOnlyId === true ? null : (
							<div className="col-md-6" style={{wordBreak: "normal"}}>
								<ActionLink label="Odkryj" handleClick={() => this.personalize(value)} />
							</div>
						)}
					</div>
				);
			} else {
				if (applicantUser) {
					return (
						<span>{value.firstName ? value.firstName : ''} {value.lastName ? value.lastName : ''}</span>
					);
				} else if (managerUser) {
					return (
						<span>{value.managerFullName}</span>
					);
				} else {
					return (
						<span>{value.id} : {value.firstName ? value.firstName : ''} {value.lastName ? value.lastName : ''}</span>
					);
				}
			}
		} else if (viewType === 'DETAILS') {
			if (empty || publicUser || !hidden || showOnlyId) {
				let v;
				if (empty) {
					v = '-';
				} else if (publicUser) {
					v = 'Użytkownik niezalogowany';
				} else if (showOnlyId) {
					v = value.id;
				} else if (managerUser) {
					v = value.managerFullName;
				} else if (applicantUser) {
					v = `${value.firstName ? value.firstName : ''} ${value.lastName ? value.lastName : ''}`;
				} else {
					v = `${value.id} : ${value.firstName ? value.firstName : ''} ${value.lastName ? value.lastName : ''}`;
				}
				if (v && typeof v === 'string') {
					v = v.trim();
				}
				// console.log('***', `[${v}]`);
				// console.log('***', validator);
				// console.log('***', validators);
				// console.log('***', validator !== undefined);
				return (
					<InputTextComponent
						id={id}
						label={label}
						colClass={colClass}
						value={v}
						viewMode="VIEW"
						rendered={rendered}
						validateViewMode={validator !== undefined}
						validator={validator}
						validators={validators}

					/>
				);
			} else {
				return this.renderDetailWithPersonalizeOption();
			}
		}
	}
}

RodoUserComponent.defaultProps = {
	baseRestApiUrl: 'http://localhost:8080/o/rest-api',
	viewType: 'DETAILS',
	insideTable: false,
	formGroup: true,
	showLabel: true,
	titleElement: false,
	titleElementShowId: false,
	titleElementClass: 'col-md-12',
	iconSide: 'left',
	showOnlyId: false,
	userType: 'USER',
	validateViewMode: false,
	validators: 'required',
};

RodoUserComponent.propTypes = {
	baseRestApiUrl: PropTypes.string,
	colClass: PropTypes.string,
	formGroup: PropTypes.bool,
	iconColor: PropTypes.string,
	iconName: PropTypes.string,
	iconSide: PropTypes.string,
	iconSize: PropTypes.string,
	id: PropTypes.string.isRequired,
	insideTable: PropTypes.bool,
	label: PropTypes.string.isRequired,
	onError: PropTypes.func,
	rendered: PropTypes.bool,
	requestId: PropTypes.number,
	showLabel: PropTypes.bool,
	showOnlyId: PropTypes.bool,
	titleElement: PropTypes.bool,
	titleElementClass: PropTypes.string,
	userType: PropTypes.string,
	validator: PropTypes.object,
	validators: PropTypes.string,
	value: PropTypes.object,
	viewType: PropTypes.string,
};

export default RodoUserComponent;

==> react-gui-common-1.3.225.tgz: package/src/components/RodoUserComponent.js <==
/* eslint-disable max-len */
/* eslint-disable react/jsx-handler-names */
import React from 'react';
import PropTypes from 'prop-types';
import ActionLink from './ActionLink';
import BaseService from '../baseContainers/BaseService';
import InputTextComponent from './inputs/InputTextComponent';

// eslint-disable-next-line import/no-extraneous-dependencies
/*
import {
	ActionLink,
	BaseService,
	InputTextComponent,
} from 'react-gui-common';
*/

class RodoService extends BaseService {
	constructor(domain) {
		super(domain);
		this.path = 'common/rodo';
	}

	personalize(id, userType) {
		return this.fetch(`${this.domain}/${this.path}/personalize/${id}?type=${userType}`, {
			method: 'GET',
		}).then(res => {
			return Promise.resolve(res);
		});
	}
}

class RodoUserComponent extends React.Component {
	constructor(props) {
		super(props);
		this.rodoService = new RodoService(props.baseRestApiUrl);
		this.state = {};
	}

	personalize(user) {
		console.log(`personalize, user.id=${user.id}`);
		const { onError, userType, requestId } = this.props;
		let id;
		if (userType === 'USER' || userType === 'PUBLIC_UNIT_MANAGER') {
			id = user.id;
		} else {
			id = requestId;
		}
		this.rodoService
			.personalize(id, userType)
			.then(u => {
				user.unhidden = true;
				if (userType === 'PUBLIC_UNIT_MANAGER') {
					user.managerFullName = u.firstName;
					user.filled = u.firstName !== undefined && u.firstName !== '';
				} else {
					user.firstName = u.firstName;
					user.lastName = u.lastName;
					user.filled =
						u.firstName !== undefined &&
						u.firstName !== '' &&
						u.lastName !== undefined &&
						u.lastName !== '';
				}
				console.log('&++++', user);
				this.setState({ user });
			})
			.catch(err => {
				if (onError) {
					onError(err.message);
				}
			});
	}

	renderDetailWithPersonalizeOption() {
		const {
			id,
			colClass,
			insideTable,
			formGroup,
			label,
			showLabel,
			titleElement,
			titleElementClass,
			iconName,
			iconColor,
			iconSide,
			iconSize,
			value,
			showOnlyId,
			rendered,
			userType,
			validator,
			validators,
		} = this.props;

		const managerUser = userType === 'PUBLIC_UNIT_MANAGER';
		const applicantUser =
			userType === 'DATA_ACCESS_REQ_APPLICANT' || userType === 'QUERY_REQ_APPLICANT';

		if (rendered) {
			return (
				<div className={insideTable ? '' : titleElement ? titleElementClass : colClass}>
					<div className={insideTable ? '' : 'row'}>
						<div className={insideTable ? '' : `col-md-12 ${formGroup ? 'form-group' : ''}`}>
							{label !== undefined && showLabel && !titleElement ? (
								<label className="p-label" htmlFor={id} style={{ width: '100%' }}>
									{label}
								</label>
							) : null}
							<span
								className={`p-inputtext-view icon_text ${titleElement ? ' title-element' : ''} ${
									iconName !== undefined ? iconColor : ''
								}`}
							>
								{iconSide === 'left' && iconName !== undefined ? (
									<i className={`icon mdi ${iconName} ${iconSize}`} />
								) : null}
								{managerUser || applicantUser ? '********' : value.id}
								{iconSide === 'right' && iconName !== undefined ? (
									<i className={`icon mdi ${iconName} ${iconSize}`} />
								) : null}
								{showOnlyId ? null : (
									<span style={{ marginLeft: '10px' }}>
										<ActionLink label="Odkryj" handleClick={() => this.personalize(value)} />
									</span>
								)}
							</span>
							<div aria-live="assertive">
								{validator
									? validator.message(
											id,
											label,
											value.filled === false ? null : 'filled',
											validators
									  )
									: null}
							</div>
						</div>
					</div>
				</div>
			);
		} else {
			return <span />;
		}
	}

	render() {
		const {
			id,
			label,
			colClass,
			value,
			viewType,
			rendered,
			showOnlyId,
			userType,
			validator,
			validators,
		} = this.props;
		let hidden = true;
		if (
			userType === 'USER' ||
			userType === 'DATA_ACCESS_REQ_APPLICANT' ||
			userType === 'QUERY_REQ_APPLICANT'
		) {
			hidden = value === undefined || (!value.firstName && !value.lastName);
		} else if (userType === 'PUBLIC_UNIT_MANAGER') {
			hidden = value === undefined || !value.managerFullName;
		}
		if (value && value.hidden === false) {
			hidden = false;
		}
		if (value && value.unhidden === true) {
			hidden = false;
		}
		const publicUser = value !== undefined && value.id === 0;
		const empty =
			value === undefined ||
			value == null ||
			(userType === 'USER' && value && (value.id === undefined || value.id === null));
		const applicantUser =
			userType === 'DATA_ACCESS_REQ_APPLICANT' || userType === 'QUERY_REQ_APPLICANT';
		const managerUser = userType === 'PUBLIC_UNIT_MANAGER';
		// console.log(`+++ hidden=${hidden}, publicUser=${publicUser}, empty=${empty}, showOnlyId=${showOnlyId}, rendered=${rendered}, userType=${userType}, user=${JSON.stringify(value)}`);
		// console.log('++++managerUserHidden:', managerUserHidden);
		if (viewType === 'LIST') {
			if (empty) {
				return <span>-</span>;
			} else if (publicUser) {
				return <span>Użytkownik niezalogowany</span>;
			} else if (hidden || showOnlyId) {
				return (
					<div className="row">
						<div className="col-md-6">{applicantUser || managerUser ? '********' : value.id}</div>
						{showOnlyId === true ? null : (
							<div className="col-md-6" style={{ wordBreak: 'normal' }}>
								<ActionLink label="Odkryj" handleClick={() => this.personalize(value)} />
							</div>
						)}
					</div>
				);
			} else {
				if (applicantUser) {
					return (
						<span>
							{value.firstName ? value.firstName : ''} {value.lastName ? value.lastName : ''}
						</span>
					);
				} else if (managerUser) {
					return <span>{value.managerFullName}</span>;
				} else {
					return (
						<span>
							{value.id} : {value.firstName ? value.firstName : ''}{' '}
							{value.lastName ? value.lastName : ''}
						</span>
					);
				}
			}
		} else if (viewType === 'DETAILS') {
			if (empty || publicUser || !hidden || showOnlyId) {
				let v;
				if (empty) {
					v = '-';
				} else if (publicUser) {
					v = 'Użytkownik niezalogowany';
				} else if (showOnlyId) {
					v = value.id;
				} else if (managerUser) {
					v = value.managerFullName;
				} else if (applicantUser) {
					v = `${value.firstName ? value.firstName : ''} ${value.lastName ? value.lastName : ''}`;
				} else {
					v = `${value.id} : ${value.firstName ? value.firstName : ''} ${
						value.lastName ? value.lastName : ''
					}`;
				}
				if (v && typeof v === 'string') {
					v = v.trim();
				}
				// console.log('***', `[${v}]`);
				// console.log('***', validator);
				// console.log('***', validators);
				// console.log('***', validator !== undefined);
				return (
					<InputTextComponent
						id={id}
						label={label}
						colClass={colClass}
						value={v}
						viewMode="VIEW"
						rendered={rendered}
						validateViewMode={validator !== undefined}
						validator={validator}
						validators={validators}
					/>
				);
			} else {
				return this.renderDetailWithPersonalizeOption();
			}
		}
	}
}

RodoUserComponent.defaultProps = {
	baseRestApiUrl: 'http://localhost:8080/o/rest-api',
	viewType: 'DETAILS',
	insideTable: false,
	formGroup: true,
	showLabel: true,
	titleElement: false,
	titleElementShowId: false,
	titleElementClass: 'col-md-12',
	iconSide: 'left',
	showOnlyId: false,
	userType: 'USER',
	validateViewMode: false,
	validators: 'required',
};

RodoUserComponent.propTypes = {
	baseRestApiUrl: PropTypes.string,
	colClass: PropTypes.string,
	formGroup: PropTypes.bool,
	iconColor: PropTypes.string,
	iconName: PropTypes.string,
	iconSide: PropTypes.string,
	iconSize: PropTypes.string,
	id: PropTypes.string.isRequired,
	insideTable: PropTypes.bool,
	label: PropTypes.string.isRequired,
	onError: PropTypes.func,
	rendered: PropTypes.bool,
	requestId: PropTypes.number,
	showLabel: PropTypes.bool,
	showOnlyId: PropTypes.bool,
	titleElement: PropTypes.bool,
	titleElementClass: PropTypes.string,
	userType: PropTypes.string,
	validator: PropTypes.object,
	validators: PropTypes.string,
	value: PropTypes.object,
	viewType: PropTypes.string,
};

export default RodoUserComponent;
